# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ....core.datetime_utils import serialize_datetime
from .provider_filter import ProviderFilter

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class ProviderOperations(pydantic.BaseModel):
    name: str = pydantic.Field()
    """
    Name of the operation.
    """

    supported: bool = pydantic.Field()
    """
    Whether the operation is supported by the provider.
    """

    required_fields: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of fields in the request body that are required by the provider for this
    operation. Due to limitations of the OpenAPI format these fields may be marked as
    optional, even though they are in fact required by this provider.
    """

    supported_response_fields: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of fields that may be returned in the response body. Any fields not listed in this array are not supported by this provider and will not be returned in the response body.
    """

    filters: typing.Optional[typing.List[ProviderFilter]] = pydantic.Field(default=None)
    """
    Filters that can be applied to this operation.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ....core.datetime_utils import serialize_datetime
from .ping_one_credential import PingOneCredential

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class IdentityPingOne(pydantic.BaseModel):
    """
    Configuration for the PingOne Identity Platform
    """

    auth_url: str = pydantic.Field()
    """
    The URL base for making authentication requests to PingOne.
    """

    client_id: str = pydantic.Field()
    """
    The client ID for the application set up as a worker.
    """

    credential: PingOneCredential
    organization_id: str = pydantic.Field()
    """
    The organization ID that the client app is a part of.
    """

    url: str = pydantic.Field()
    """
    URL for the PingOne API. This should be the base URL for the API, without any path components.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ....core.datetime_utils import serialize_datetime
from .priority_mapping import PriorityMapping
from .status_mapping import StatusMapping

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class ValueMapping(pydantic.BaseModel):
    issue_type: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optionally restrict this value mapping to a specific issue type. If not provided, the mapping will apply to all issue types.
    """

    priority: typing.Optional[PriorityMapping] = pydantic.Field(default=None)
    """
    Remap the standard Synqly priorities to custom values.
    """

    project_id: str = pydantic.Field()
    """
    ID of the project this value mapping is associated with. ID of "\*" is used to apply to all projects.
    """

    status: typing.Optional[StatusMapping] = pydantic.Field(default=None)
    """
    Remap the standard Synqly statuses to custom values.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ....core.datetime_utils import serialize_datetime
from ...capabilities_base.types.category_id import CategoryId
from .capabilities_provider_config import CapabilitiesProviderConfig
from .provider_credential_config import ProviderCredentialConfig

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class Provider(pydantic.BaseModel):
    name: str = pydantic.Field()
    """
    Name of the Provider.
    """

    description: str = pydantic.Field()
    """
    Description of what this Provider does.
    """

    categories: typing.List[CategoryId] = pydantic.Field()
    """
    Categories that this Provider implements.
    """

    picture: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL of the icon representing this type of Provider.
    """

    supported_operations: typing.Any = pydantic.Field()
    """
    Operations that this Provider implements.
    """

    credentials: typing.List[ProviderCredentialConfig] = pydantic.Field()
    """
    List of credential types that this Provider supports.
    """

    provider_config: typing.Dict[str, CapabilitiesProviderConfig] = pydantic.Field()
    """
    Details on the specific configuration options for this Provider.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from .connector import Connector
from .filter_operation import FilterOperation
from .filter_type import FilterType
from .list_connectors_capabilities_response import ListConnectorsCapabilitiesResponse
from .list_providers_capabilities_response import ListProvidersCapabilitiesResponse
from .provider_capabilities import ProviderCapabilities
from .provider_filter import ProviderFilter
from .provider_operations import ProviderOperations

__all__ = [
    "Connector",
    "FilterOperation",
    "FilterType",
    "ListConnectorsCapabilitiesResponse",
    "ListProvidersCapabilitiesResponse",
    "ProviderCapabilities",
    "ProviderFilter",
    "ProviderOperations",
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..........core.datetime_utils import serialize_datetime

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class ManagedEntity(pydantic.BaseModel):
    """
    The Managed Entity object describes the type and version of an entity, such as a policy or configuration.
    """

    data: typing.Optional[typing.Any] = pydantic.Field(default=None)
    """
    The managed entity content as a JSON object.
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the managed entity.
    """

    type: typing.Optional[str] = pydantic.Field(default=None)
    """
    The managed entity type. For example: <code>policy</code>, <code>user</code>, <code>organizational unit</code>, <code>device</code>.
    """

    uid: typing.Optional[str] = pydantic.Field(default=None)
    """
    The identifier of the managed entity.
    """

    version: typing.Optional[str] = pydantic.Field(default=None)
    """
    The version of the managed entity. For example: <code>1.2.3</code>.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ....core.datetime_utils import serialize_datetime
from ...permissionset_base.types.permissions import Permissions
from .api_permission_map import ApiPermissionMap
from .resource_restrictions import ResourceRestrictions

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class PermissionSet(pydantic.BaseModel):
    name: Permissions
    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Description of when the permission set should be used and what permissions are granted by the permission set.
    """

    resource_restrictions: typing.Optional[typing.List[ResourceRestrictions]] = pydantic.Field(default=None)
    """
    Resources that can be used with this permission set
    """

    permissions: ApiPermissionMap = pydantic.Field()
    """
    API permissions granted by the permission set.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from .types import (
    Connector,
    FilterOperation,
    FilterType,
    ListConnectorsCapabilitiesResponse,
    ListProvidersCapabilitiesResponse,
    ProviderCapabilities,
    ProviderFilter,
    ProviderOperations,
)

__all__ = [
    "Connector",
    "FilterOperation",
    "FilterType",
    "ListConnectorsCapabilitiesResponse",
    "ListProvidersCapabilitiesResponse",
    "ProviderCapabilities",
    "ProviderFilter",
    "ProviderOperations",
]



# This file was auto-generated by Fern from our API Definition.

from .types import (
    CapabilitiesProviderConfig,
    Category,
    ListCategoryCapabilitiesResponse,
    ListProviderCapabilitiesResponse,
    Provider,
    ProviderCredentialConfig,
)

__all__ = [
    "CapabilitiesProviderConfig",
    "Category",
    "ListCategoryCapabilitiesResponse",
    "ListProviderCapabilitiesResponse",
    "Provider",
    "ProviderCredentialConfig",
]



# This file was auto-generated by Fern from our API Definition.

from .capabilities_provider_config import CapabilitiesProviderConfig
from .category import Category
from .list_category_capabilities_response import ListCategoryCapabilitiesResponse
from .list_provider_capabilities_response import ListProviderCapabilitiesResponse
from .provider import Provider
from .provider_credential_config import ProviderCredentialConfig

__all__ = [
    "CapabilitiesProviderConfig",
    "Category",
    "ListCategoryCapabilitiesResponse",
    "ListProviderCapabilitiesResponse",
    "Provider",
    "ProviderCredentialConfig",
]
